# seven_jd

## 天志互联Python京东sdk库


### 1.0.1 更新内容
* 京东sdk库初始工程

### 1.0.2 更新内容
* 增加MiniappMixUserInfoRequest(jingdong.miniapp.mixUserInfo)

### 1.0.3 更新内容
* 更新版本到jos-python3-open-api-sdk-2.0-2023-10-10

### 1.0.5 更新内容
* 更新版本到jos-python3-open-api-sdk-2.0-2023-10-16

### 1.0.6 更新内容
* 更新版本到jos-python3-open-api-sdk-2.0-2023-10-18

### 1.0.7 更新内容
* 更新版本到jos-python3-open-api-sdk-2.0-2023-11-13

### 1.0.8 更新内容
* 更新版本到jos-python3-open-api-sdk-2.0-2023-11-14

### 1.0.9 更新内容
* 更新版本到jos-python3-open-api-sdk-2.0-2023-12-04

### 1.0.10 更新内容
* 更新版本到jos-python3-open-api-sdk-2.0-2023-12-06